Composer class

Add composing to hashtag decorated text.

Expected to be used when Japanese letters are typed.

Constructors

Composer({required String sourceText, required List<Detection?> detections, required TextRange composing, required int selection, required TextStyle detectedStyle})

Properties

composing → TextRange
final
detectedStyle → TextStyle
final
detections → List<Detection?>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → int
final
sourceText → String
final

Methods

getComposedTextSpan() → TextSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
typingDetection() → Detection?

Operators

operator ==(Object other) → bool
The equality operator.
inherited