Detection class

DataModel to explain the unit of word in decoration system

Inheritance

Constructors

Detection({required TextRange range, TextStyle? style, int? emojiStartPoint})

Properties

emojiStartPoint → int?
final
hashCode → int
The hash code for this object.
no setterinherited
range → TextRange
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
final

Methods

compareTo(Detection other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited