Detector class

Hold functions to detect text

Return the list of Detection in getDetections

Constructors

Detector({required TextStyle textStyle, required TextStyle detectedStyle, required RegExp detectionRegExp})

Properties

detectedStyle → TextStyle
final
detectionRegExp → RegExp
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
final

Methods

getDetections(String copiedText) → List<Detection>
Return the list of decorations with tagged and untagged text
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited