DetectableEditableText class

Show detected text while user is inputting text.

EditableText which detects the text with detectionRegExp

Inheritance

Constructors

DetectableEditableText({Key? key, FocusNode? focusNode, required TextEditingController controller, required TextStyle basicStyle, required TextStyle detectedStyle, required RegExp detectionRegExp, required Color cursorColor, required ValueChanged<String>? onDetectionTyped, required VoidCallback? onDetectionFinished, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, int? maxLines, int? minLines, TextInputType? keyboardType, bool? autofocus, bool obscureText = false, bool readOnly = false, bool forceLine = true, ToolbarOptions toolbarOptions = const ToolbarOptions(copy: true, cut: true, paste: true, selectAll: true), bool autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, StrutStyle? strutStyle, TextAlign textAlign = TextAlign.start, TextDirection? textDirection, TextCapitalization textCapitalization = TextCapitalization.none, Locale? locale, double? textScaleFactor, bool expands = false, Color? selectionColor, TextSelectionControls? selectionControls, TextInputAction? textInputAction, VoidCallback? onEditingComplete, SelectionChangedCallback? onSelectionChanged, VoidCallback? onSelectionHandleTapped, List<TextInputFormatter>? inputFormatters, double cursorWidth = 2.0, Radius? cursorRadius, bool cursorOpacityAnimates = false, Offset? cursorOffset, bool paintCursorAboveText = false, BoxHeightStyle selectionHeightStyle = BoxHeightStyle.tight, BoxWidthStyle selectionWidthStyle = BoxWidthStyle.tight, Brightness keyboardAppearance = Brightness.light, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollController? scrollController, ScrollPhysics? scrollPhysics, bool? showCursor, bool showSelectionHandles = false, bool rendererIgnoresPointer = true, Color backgroundCursorColor = CupertinoColors.inactiveGray, bool enableInteractiveSelection = true, Color? autocorrectionTextRectColor, String obscuringCharacter = '•', AppPrivateCommandCallback? onAppPrivateCommand, MouseCursor? mouseCursor, Iterable<String>? autofillHints, String? restorationId, double? cursorHeight})

Properties

autocorrect → bool
Whether to enable autocorrection.
finalinherited
autocorrectionTextRectColor → Color?
The color to use when painting the autocorrection Rect.
finalinherited
autofillClient → AutofillClient?
The AutofillClient that controls this input field's autofill behavior.
finalinherited
autofillHints → Iterable<String>?
A list of strings that helps the autofill service identify the type of this text input.
finalinherited
autofocus → bool
Whether this text field should focus itself if nothing else is already focused.
finalinherited
backgroundCursorColor → Color
The color to use when painting the background cursor aligned with the text while rendering the floating cursor.
finalinherited
clipBehavior → Clip
The content will be clipped (or not) according to this option.
finalinherited
contentInsertionConfiguration → ContentInsertionConfiguration?
Configuration of handler for media content inserted via the system input method.
finalinherited
contextMenuBuilder → EditableTextContextMenuBuilder?
Builds the text selection toolbar when requested by the user.
finalinherited
controller → TextEditingController
Controls the text being edited.
finalinherited
cursorColor → Color
The color to use when painting the cursor.
finalinherited
cursorHeight → double?
How tall the cursor will be.
finalinherited
cursorOffset → Offset?
The offset that is used, in pixels, when painting the cursor on screen.
finalinherited
cursorOpacityAnimates → bool
Whether the cursor will animate from fully transparent to fully opaque during each cursor blink.
finalinherited
cursorRadius → Radius?
How rounded the corners of the cursor should be.
finalinherited
cursorWidth → double
How thick the cursor will be.
finalinherited
detectedStyle → TextStyle
final
detectionRegExp → RegExp
final
dragStartBehavior → DragStartBehavior
Determines the way that drag start behavior is handled.
finalinherited
enableIMEPersonalizedLearning → bool
Whether to enable that the IME update personalized data such as typing history and user dictionary data.
finalinherited
enableInlinePrediction → bool?
Whether to enable inline predictive text.
finalinherited
enableInteractiveSelection → bool
Whether to enable user interface affordances for changing the text selection.
finalinherited
enableSuggestions → bool
Whether to show input suggestions as the user types.
finalinherited
expands → bool
Whether this widget's height will be sized to fill its parent.
finalinherited
focusNode → FocusNode
Controls whether this widget has keyboard focus.
finalinherited
forceLine → bool
Whether the text will take the full width regardless of the text width.
finalinherited
groupId → Object
The group identifier for the TextFieldTapRegion of this text field.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintLocales → List<Locale>?
List of the languages that the user is expected to use.
finalinherited
inputFormatters → List<TextInputFormatter>?
Optional input validation and formatting overrides.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness
The appearance of the keyboard.
finalinherited
keyboardType → TextInputType
The type of keyboard to use for editing the text.
finalinherited
locale → Locale?
Used to select a font when the same Unicode character can be rendered differently, depending on the locale.
finalinherited
magnifierConfiguration → TextMagnifierConfiguration
The configuration for the magnifier to use with selections in this text field.
finalinherited
maxLines → int?
The maximum number of lines to show at one time, wrapping if necessary.
finalinherited
minLines → int?
The minimum number of lines to occupy when the content spans fewer lines.
finalinherited
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
obscureText → bool
Whether to hide the text being edited (e.g., for passwords).
finalinherited
obscuringCharacter → String
Character used for obscuring text if obscureText is true.
finalinherited
onAppPrivateCommand → AppPrivateCommandCallback?
This is used to receive a private command from the input method.
finalinherited
onChanged → ValueChanged<String>?
Called when the user initiates a change to the TextField's value: when they have inserted or deleted text.
finalinherited
onDetectionFinished → VoidCallback?
final
onDetectionTyped → ValueChanged<String>?
final
onEditingComplete → VoidCallback?
Called when the user submits editable content (e.g., user presses the "done" button on the keyboard).
finalinherited
onSelectionChanged → SelectionChangedCallback?
Called when the user changes the selection of text (including the cursor location).
finalinherited
onSelectionHandleTapped → VoidCallback?
A callback that's optionally invoked when a selection handle is tapped.
finalinherited
onSubmitted → ValueChanged<String>?
Called when the user indicates that they are done editing the text in the field.
finalinherited
onTapOutside → TapRegionCallback?
Called for each tap down that occurs outside of the TextFieldTapRegion group when the text field is focused.
finalinherited
onTapUpOutside → TapRegionUpCallback?
Called for each tap up that occurs outside of the TextFieldTapRegion group when the text field is focused.
finalinherited
paintCursorAboveText → bool
If the cursor should be painted on top of the text or underneath it.
finalinherited
readOnly → bool
Whether the text can be changed.
finalinherited
rendererIgnoresPointer → bool
Whether the caller will provide gesture handling (true), or if the EditableText is expected to handle basic gestures (false).
finalinherited
restorationId → String?
Restoration ID to save and restore the scroll offset of the EditableText.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled → bool
Whether iOS 14 Scribble features are enabled for this widget.
finalinherited
scrollBehavior → ScrollBehavior?
A ScrollBehavior that will be applied to this widget individually.
finalinherited
scrollController → ScrollController?
The ScrollController to use when vertically scrolling the input.
finalinherited
scrollPadding → EdgeInsets
Configures the padding for the edges surrounding a Scrollable when the text field scrolls into view.
finalinherited
scrollPhysics → ScrollPhysics?
The ScrollPhysics to use when vertically scrolling the input.
finalinherited
selectAllOnFocus → bool
Whether this field should select all text when gaining focus.
finalinherited
selectionColor → Color?
The color to use when painting the selection.
finalinherited
selectionControls → TextSelectionControls?
Optional delegate for building the text selection handles.
finalinherited
selectionEnabled → bool
Same as enableInteractiveSelection.
no setterinherited
selectionHeightStyle → BoxHeightStyle
Controls how tall the selection highlight boxes are computed to be.
finalinherited
selectionWidthStyle → BoxWidthStyle
Controls how wide the selection highlight boxes are computed to be.
finalinherited
showCursor → bool
Whether to show cursor.
finalinherited
showSelectionHandles → bool
Whether to show selection handles.
finalinherited
smartDashesType → SmartDashesType
Whether to allow the platform to automatically format dashes.
finalinherited
smartQuotesType → SmartQuotesType
Whether to allow the platform to automatically format quotes.
finalinherited
spellCheckConfiguration → SpellCheckConfiguration?
Configuration that details how spell check should be performed.
finalinherited
strutStyle → StrutStyle
The strut style used for the vertical layout.
no setterinherited
style → TextStyle
The text style to use for the editable text.
finalinherited
stylusHandwritingEnabled → bool
Whether this input supports stylus handwriting, where the user can write directly on top of a field.
finalinherited
textAlign → TextAlign
How the text should be aligned horizontally.
finalinherited
textCapitalization → TextCapitalization
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
finalinherited
textDirection → TextDirection?
The directionality of the text.
finalinherited
textHeightBehavior → TextHeightBehavior?
Defines how to apply TextStyle.height over and under text.
finalinherited
textInputAction → TextInputAction?
The type of action button to use with the soft keyboard.
finalinherited
textScaleFactor → double?
Deprecated. Will be removed in a future version of Flutter. Use textScaler instead.
finalinherited
textScaler → TextScaler?
The font scaling strategy to use when laying out and rendering the text.
finalinherited
textWidthBasis → TextWidthBasis
Defines how to measure the width of the rendered text.
finalinherited
toolbarOptions → ToolbarOptions
Configuration of toolbar options.
finalinherited
undoController → UndoHistoryController?
Controls the undo state of the current editable text.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → DetectableEditableTextState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited