DetectableEditableTextState class

State of DetectableEditableText

Return detected text by using functions in Detector

Inheritance

Properties

autofillId → String
The unique identifier of this AutofillClient.
no setterinherited
clipboardStatus → ClipboardStatusNotifier
Detects whether the clipboard can paste.
finalinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
contextMenuAnchors → TextSelectionToolbarAnchors
Returns the anchor points for the default context menu.
no setterinherited
contextMenuButtonItems → List<ContextMenuButtonItem>
Returns the ContextMenuButtonItems representing the buttons in this platform's default selection menu for EditableText.
no setterinherited
copyEnabled → bool
Whether copy is enabled.
no setterinherited
currentAutofillScope → AutofillScope?
The AutofillScope this TextInputClient belongs to, if any.
no setterinherited
currentTextEditingValue → TextEditingValue
The current state of the TextEditingValue held by this client.
no setterinherited
cursorBlinkInterval → Duration
The cursor blink interval (the amount of time the cursor is in the "on" state or the "off" state). A complete cursor blink period is twice this value (half on, half off).
no setterinherited
cursorCurrentlyVisible → bool
Whether the blinking cursor is actually visible at this precise moment (it's hidden half the time, since it blinks).
no setterinherited
cutEnabled → bool
Whether cut is enabled.
no setterinherited
detector ↔ Detector
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
liveTextInputEnabled → bool
Whether Live Text input is enabled.
no setterinherited
lookUpEnabled → bool
Whether look up is enabled.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
pasteEnabled → bool
Whether paste is enabled.
no setterinherited
prevTypingDetection ↔ Detection?
getter/setter pair
renderEditable → RenderEditable
The renderer for this widget's descendant.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchWebEnabled → bool
Whether search web is enabled.
no setterinherited
selectAllEnabled → bool
Whether select all is enabled.
no setterinherited
selectionOverlay → TextSelectionOverlay?
The current status of the text selection handles.
no setterinherited
shareEnabled → bool
Whether share is enabled.
no setterinherited
spellCheckConfiguration → SpellCheckConfiguration
Configuration that determines how spell check will be performed.
no setterinherited
spellCheckEnabled → bool
Whether or not spell check is enabled.
no setterinherited
spellCheckResults ↔ SpellCheckResults?
The most up-to-date spell check results for text input.
getter/setter pairinherited
textEditingValue → TextEditingValue
Gets the current text input.
no setterinherited
textInputConfiguration → TextInputConfiguration
The TextInputConfiguration that describes this AutofillClient.
no setterinherited
wantKeepAlive → bool
Whether the current instance should be kept alive.
no setterinherited
widget → DetectableEditableText
The current configuration.
no setteroverride

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
autofill(TextEditingValue value) → void
Requests this AutofillClient update its TextEditingValue to the given value.
inherited
beginBatchEdit() → void
Begins a new batch edit, within which new updates made to the text editing value will not be sent to the platform text input plugin.
inherited
bringIntoView(TextPosition position) → void
Brings the provided TextPosition into the visible area of the text input.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
buildTextSpan() → TextSpan
Builds TextSpan from current editing value.
override
buttonItemsForToolbarOptions([TargetPlatform? targetPlatform]) → List<ContextMenuButtonItem>?
Returns the ContextMenuButtonItems for the given ToolbarOptions.
inherited
connectionClosed() → void
Platform notified framework of closed connection.
inherited
copySelection(SelectionChangedCause cause) → void
Copy current selection to Clipboard.
inherited
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
cutSelection(SelectionChangedCause cause) → void
Cut current selection to Clipboard.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didChangeInputControl(TextInputControl? oldControl, TextInputControl? newControl) → void
The framework calls this method to notify that the text input control has been changed.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() → Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) → Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) → Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() → Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
didUpdateWidget(covariant EditableText oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
endBatchEdit() → void
Ends the current batch edit started by the last call to beginBatchEdit, and send currentTextEditingValue to the text input plugin if needed.
inherited
findSuggestionSpanAtCursorIndex(int cursorIndex) → SuggestionSpan?
Finds specified SuggestionSpan that matches the provided index using binary search.
inherited
getGlyphHeights() → ({double endGlyphHeight, double startGlyphHeight})
Gets the line heights at the start and end of the selection for the given EditableTextState.
inherited
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) → bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
hideMagnifier() → void
Hides the magnifier.
inherited
hideToolbar([bool hideHandles = true]) → void
Hides the text selection toolbar.
inherited
initState() → void
Called when this object is inserted into the tree.
override
insertContent(KeyboardInsertedContent content) → void
Notify client about new content insertion from Android keyboard.
inherited
insertTextPlaceholder(Size size) → void
Requests that the client add a text placeholder to reserve visual space in the text.
inherited
lookUpSelection(SelectionChangedCause cause) → Future<void>
Look up the current selection, as in the "Look Up" edit menu button on iOS.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFocusReceived() → bool
Notifies the client that the platform moved focus back to this input.
inherited
pasteText(SelectionChangedCause cause) → Future<void>
Paste text from Clipboard.
inherited
performAction(TextInputAction action) → void
Requests that this client perform the given action.
inherited
performPrivateCommand(String action, Map<String, dynamic> data) → void
Request from the input method that this client perform the given private command.
inherited
performSelector(String selectorName) → void
Performs the specified MacOS-specific selector from the NSStandardKeyBindingResponding protocol or user-specified selector from DefaultKeyBinding.Dict.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeTextPlaceholder() → void
Requests that the client remove the text placeholder.
inherited
requestKeyboard() → void
Express interest in interacting with the keyboard.
inherited
searchWebForSelection(SelectionChangedCause cause) → Future<void>
Launch a web search on the current selection, as in the "Search Web" edit menu button on iOS.
inherited
selectAll(SelectionChangedCause cause) → void
Select the entire text value.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
shareSelection(SelectionChangedCause cause) → Future<void>
Launch the share interface for the current selection, as in the "Share..." edit menu button on iOS.
inherited
showAutocorrectionPromptRect(int start, int end) → void
Requests that this client display a prompt rectangle for the given text range, to indicate the range of text that will be changed by a pending autocorrection.
inherited
showMagnifier(Offset positionToShow) → void
Shows the magnifier at the position given by positionToShow, if no magnifier exists.
inherited
showSpellCheckSuggestionsToolbar() → bool
Shows toolbar with spell check suggestions of misspelled words that are available for click-and-replace.
inherited
showToolbar() → bool
Shows the selection toolbar at the location of the current cursor.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleToolbar([bool hideHandles = true]) → void
Toggles the visibility of the toolbar.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateEditingValue(TextEditingValue value) → void
Requests that this client update its editing state to the given value.
inherited
updateFloatingCursor(RawFloatingCursorPoint point) → void
Updates the floating cursor position and state.
inherited
updateKeepAlive() → void
Ensures that any AutomaticKeepAlive ancestors are in a good state, by firing a KeepAliveNotification or triggering the KeepAliveHandle as appropriate.
inherited
userUpdateTextEditingValue(TextEditingValue value, SelectionChangedCause? cause) → void
Indicates that the user has requested the delegate to replace its current text editing state with value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited