DetectableText class

Show detected text only to be shown

onTap is called when a tagged text is tapped.

Inheritance

Constructors

DetectableText({required String text, required RegExp detectionRegExp, TextStyle? basicStyle, TextStyle? detectedStyle, dynamic onTap(String)?, TextAlign textAlign = TextAlign.start, TextDirection? textDirection, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, double textScaleFactor = 1.0, int? maxLines, Locale? locale, StrutStyle? strutStyle, TextWidthBasis textWidthBasis = TextWidthBasis.parent, TextHeightBehavior? textHeightBehavior, String trimExpandedText = 'show less', String trimCollapsedText = 'read more', TextStyle? moreStyle, TextStyle? lessStyle, Color? colorClickableText, int trimLength = 240, int trimLines = 2, TrimMode trimMode = TrimMode.Length, String delimiter = _kEllipsis + ' ', dynamic callback(bool val)?})

Properties

basicStyle → TextStyle?
final
callback → dynamic Function(bool val)?
Called when state change between expanded/compress
final
colorClickableText → Color?
final
delimiter → String
final
detectedStyle → TextStyle?
final
detectionRegExp → RegExp
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lessStyle → TextStyle?
TextStyle for compressed text
final
locale → Locale?
final
maxLines → int?
final
moreStyle → TextStyle?
TextStyle for expanded text
final
onTap → dynamic Function(String)?
final
overflow → TextOverflow
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softWrap → bool
final
strutStyle → StrutStyle?
final
text → String
final
textAlign → TextAlign
final
textDirection → TextDirection?
final
textHeightBehavior → TextHeightBehavior?
final
textScaleFactor → double
final
textWidthBasis → TextWidthBasis
final
trimCollapsedText → String
final
trimExpandedText → String
final
trimLength → int
Used on TrimMode.Length
final
trimLines → int
Used on TrimMode.Lines
final
trimMode → TrimMode
Determines the type of trim. TrimMode.Length takes into account the number of letters, while TrimMode.Lines takes into account the number of lines
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _DetectableTextState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited